Changelog
=========

0.4 (2023-10-06)
------------------
- Better Stealth. [Vinyzu]
- Added Support and Recommendation for Ungoogled Chromium. [Vinyzu]
- Using Bayesian Network to generate Fingerprints.
- Improved Code Runtime & Generated DocStrings. [Vinyzu]
- Added Detection Tests (see dev_test.py). [Vinyzu]
- Removed unnecessary Extension. [Vinyzu]
- Added Requirements. [Vinyzu]

0.3 (2023-09-15)
------------------
- Better Stealth. [Vinyzu]
- Better Mouse Movement. [Vinyzu]
- Improved Code Runtime & Implemented Type Hints. [Vinyzu]
- Implementation of hcaptcha-challenger & recaptcha-challenger. [Vinyzu]
- Removed unnecessary Files. [Vinyzu]

0.2 (2022-09-21)
------------------
- New Features: reCaptchaSolver, geeTestv3, geeTestv4. [Vinyzu]
- Bug Fixes. [Vinyzu]
- Stability and Speed Fixes. [Vinyzu]

0.1 (2022-09-21)
------------------
- Initial Release. [Vinyzu]
